@@ -735,6 +735,12 @@ void prefs_dialog_open(SensorsApplet *sensors_applet) {
                          1, 8, 1, 1);
 #endif
 
+        gtk_widget_set_valign(GTK_WIDGET(prefs_dialog->globals_grid), GTK_ALIGN_START);
+        gtk_widget_set_margin_start(GTK_WIDGET(prefs_dialog->globals_grid), 12);
+        gtk_widget_set_margin_end(GTK_WIDGET(prefs_dialog->globals_grid), 12);
+        gtk_widget_set_margin_top(GTK_WIDGET(prefs_dialog->globals_grid), 12);
+        gtk_widget_set_margin_bottom(GTK_WIDGET(prefs_dialog->globals_grid), 12);
+
         prefs_dialog->view = g_object_new(GTK_TYPE_TREE_VIEW,
                                           "model", GTK_TREE_MODEL(sensors_applet->sensors),
                                           "rules-hint", TRUE,
@@ -841,7 +847,7 @@ void prefs_dialog_open(SensorsApplet *sensors_applet) {
                          prefs_dialog);
 
 
-        prefs_dialog->buttons_box = GTK_VBUTTON_BOX(gtk_vbutton_box_new());
+        prefs_dialog->buttons_box = GTK_BUTTON_BOX(gtk_button_box_new(GTK_ORIENTATION_VERTICAL));
 
         gtk_button_box_set_layout(GTK_BUTTON_BOX(prefs_dialog->buttons_box),
                                   GTK_BUTTONBOX_SPREAD);
@@ -850,7 +856,8 @@ void prefs_dialog_open(SensorsApplet *sensors_applet) {
 
         gtk_box_pack_start(GTK_BOX(prefs_dialog->buttons_box), GTK_WIDGET(prefs_dialog->sensor_down_button), FALSE, FALSE, 0);
 
-        prefs_dialog->sensors_hbox = g_object_new(GTK_TYPE_HBOX,
+        prefs_dialog->sensors_hbox = g_object_new(GTK_TYPE_BOX,
+                                                  "orientation", GTK_ORIENTATION_HORIZONTAL,
                                                   "border-width", 5,
                                                   "homogeneous", FALSE,
                                                   "spacing", 5,
@@ -887,7 +894,8 @@ void prefs_dialog_open(SensorsApplet *sensors_applet) {
                          G_CALLBACK(prefs_dialog_sensor_config_button_clicked),
                          prefs_dialog);
 
-        prefs_dialog->sensor_config_hbox = g_object_new(GTK_TYPE_HBOX,
+        prefs_dialog->sensor_config_hbox = g_object_new(GTK_TYPE_BOX,
+                                                        "orientation", GTK_ORIENTATION_HORIZONTAL,
                                                         "border-width", 5,
                                                         "homogeneous", FALSE,
                                                         "spacing", 0,
@@ -897,7 +905,8 @@ void prefs_dialog_open(SensorsApplet *sensors_applet) {
                          FALSE, FALSE, 0);
 
         /* pack sensors_vbox */
-        prefs_dialog->sensors_vbox = g_object_new(GTK_TYPE_VBOX,
+        prefs_dialog->sensors_vbox = g_object_new(GTK_TYPE_BOX,
+                                                  "orientation", GTK_ORIENTATION_VERTICAL,
                                                   "border-width", 5,
                                                   "homogeneous", FALSE,
                                                   "spacing", 0,
@@ -910,22 +919,11 @@ void prefs_dialog_open(SensorsApplet *sensors_applet) {
                            GTK_WIDGET(prefs_dialog->sensor_config_hbox),
                            FALSE, FALSE, 0);
 
-        prefs_dialog->globals_alignment = g_object_new(GTK_TYPE_ALIGNMENT,
-                                                       "xalign", 0.5,
-                                                       "yalign", 0.0,
-                                                       "top-padding", 12,
-                                                       "left-padding", 12,
-                                                       "bottom-padding", 12,
-                                                       "right-padding", 12,
-                                                       NULL);
-        gtk_container_add(GTK_CONTAINER(prefs_dialog->globals_alignment),
-                          GTK_WIDGET(prefs_dialog->globals_grid));
-
         prefs_dialog->notebook = g_object_new(GTK_TYPE_NOTEBOOK,
                                               NULL);
 
         gtk_notebook_append_page(prefs_dialog->notebook,
-                                 GTK_WIDGET(prefs_dialog->globals_alignment),
+                                 GTK_WIDGET(prefs_dialog->globals_grid),
                                  gtk_label_new(_("General Options")));
 
         gtk_notebook_append_page(prefs_dialog->notebook,
